@@ -1,19 +1,6 @@
-# ----------------------------------------------------------------
-    package XML::TreePP;
-    use strict;
-    use Carp;
-    use Symbol;
-# ----------------------------------------------------------------
-    use vars qw( $VERSION );
-    $VERSION = "0.08";
-# ----------------------------------------------------------------
-    my $XML_ENCODING = "UTF-8";
-    my $INTERNAL_ENCODING = "UTF-8";
-# ----------------------------------------------------------------
-
 =head1 NAME
 
-XML::TreePP -- Pure Perl implementation for parsing/writing xml file
+XML::TreePP -- Pure Perl implementation for parsing/writing xml files
 
 =head1 SYNOPSIS
 
@@ -152,11 +139,11 @@ has attribute(s) in addition to the text node.
 
 =head2 $tpp = XML::TreePP->new();
 
-This constructor method returns a new "XML::TreePP" object.
+This constructor method returns a new XML::TreePP object.
 
 =head2 $tpp = XML::TreePP->new( %options );
 
-Its first argument is a hash variable to set one or more options 
+Its first argument is a hash variable to set one or more options
 like following:
 
 =head2 $tpp->set( option_name => $option_value );
@@ -165,28 +152,28 @@ This method sets a option value for "option_name".
 If $option_value is not defined, its option is deleted.
 Options below are available:
 
-=head2 $tpp->set( output_encoding => "UTF-8" );
+=head2 $tpp->set( output_encoding => 'UTF-8' );
 
 You can define a encoding of xml file generated by write/writefile
 methods. On Perl 5.8.x and later, you can select it from every
 encodings supported by Encode.pm. On Perl 5.6.x or before with
-Jcode.pm, you can use "Shift_JIS", "EUC-JP", "ISO-2022-JP" and
-"UTF-8". The default value is "UTF-8".
+Jcode.pm, you can use 'Shift_JIS', 'EUC-JP', 'ISO-2022-JP' and
+'UTF-8'. The default value is 'UTF-8'.
 
-=head2 $tpp->set( force_array => [ "rdf:li", "item", "-xmlns" ] );
+=head2 $tpp->set( force_array => [ 'rdf:li', 'item', '-xmlns' ] );
 
 This option allows you to specify a list of element names which
 should always be forced into an array representation
 The default value is null, it means that context of the elements
 will determine to make array or to keep it scalar.
 
-=head2 $tpp->set( first_out => [ "link", "title", "-type" ] );
+=head2 $tpp->set( first_out => [ 'link', 'title', '-type' ] );
 
 This option allows you to specify a list of element/attribute
 names which should always appears at first on output XML code.
 The default value is null, it means alphabetical order is used.
 
-=head2 $tpp->set( last_out => [ "items", "item", "entry" ] );
+=head2 $tpp->set( last_out => [ 'items', 'item', 'entry' ] );
 
 This option allows you to specify a list of element/attribute
 names which should always appears at last on output XML code.
@@ -194,9 +181,23 @@ names which should always appears at last on output XML code.
 =head2 $tpp->set( cdata_scalar_ref => 1 );
 
 This option allows you to convert a cdata section into a reference
-for scalar on parsing XML source. If this option is false, per 
+for scalar on parsing XML source. If this option is false, per
 default, cdata section is converted into a scalar.
 
+=head2 $tpp->set( user_agent => 'Mozilla/4.0 (compatible; ...)' );
+
+This option allows you to specify a HTTP_USER_AGENT string which
+is used by parsehttp() method.
+The default string is "XML-TreePP/#.##", where "#.##" is
+substituted with the version number of this library.
+
+=head2 $tpp->set( attr_prefix => '@' );
+
+This option allows you to specify a prefix character(s) which
+is inserted before each attribute names.
+The default character is '-'.
+Or set '@' to access attribute values like E4X, ECMAScript for XML.
+
 =head2 $tpp->get( "option_name" );
 
 This method returns a current option value for "option_name".
@@ -244,56 +245,70 @@ is free software; you can redistribute it and/or modify it under the same
 terms as Perl itself.
 
 =cut
-# ----------------------------------------------------------------
+
+    package XML::TreePP;
+    use strict;
+    use Carp;
+    use Symbol;
+
+    use vars qw( $VERSION );
+    $VERSION = '0.10';
+
+    my $XML_ENCODING      = 'UTF-8';
+    my $INTERNAL_ENCODING = 'UTF-8';
+    my $USER_AGENT        = 'XML-TreePP/'.$VERSION." ";
+    my $ATTR_PREFIX       = '-';
+
 sub new {
     my $package = shift;
-    my $self = {@_};
+    my $self    = {@_};
     bless $self, $package;
     $self;
 }
-# ----------------------------------------------------------------
+
 sub set {
     my $self = shift;
-    my $key = shift;
-    my $val = shift;
+    my $key  = shift;
+    my $val  = shift;
     if ( defined $val ) {
         $self->{$key} = $val;
-    } else {
+    }
+    else {
         delete $self->{$key};
     }
 }
-# ----------------------------------------------------------------
+
 sub get {
     my $self = shift;
-    my $key = shift;
+    my $key  = shift;
     $self->{$key} if exists $self->{$key};
 }
-# ----------------------------------------------------------------
+
 sub writefile {
-    my $self = shift;
-    my $file = shift;
-    my $tree = shift or Carp::croak "Invalid tree";
+    my $self   = shift;
+    my $file   = shift;
+    my $tree   = shift or Carp::croak "Invalid tree";
     my $encode = shift;
     Carp::croak "Invalid filename" unless defined $file;
     my $text = $self->write( $tree, $encode );
     &write_raw_xml( $file, $text );
 }
-# ----------------------------------------------------------------
+
 sub write {
     my $self = shift;
     my $tree = shift or Carp::croak "Invalid tree";
     my $from = $self->{internal_encoding} || $INTERNAL_ENCODING;
-    my $to = shift || $self->{output_encoding} || $XML_ENCODING;
-    my $decl = '<?xml version="1.0" encoding="'.$to.'" ?>';
+    my $to   = shift || $self->{output_encoding} || $XML_ENCODING;
+    my $decl = '<?xml version="1.0" encoding="' . $to . '" ?>';
     if ( exists $self->{first_out} ) {
         my $keys = $self->{first_out};
-        $keys = [ $keys ] unless ref $keys;
-        $self->{__first_out} = { map {$_=>1} @$keys };
+        $keys = [$keys] unless ref $keys;
+        $self->{__first_out} = { map { $_ => 1 } @$keys };
     }
     if ( exists $self->{last_out} ) {
         my $keys = $self->{last_out};
-        $keys = [ $keys ] unless ref $keys;
-        $self->{__last_out} = { map {$_=>1} @$keys };
+        $keys = [$keys] unless ref $keys;
+        $self->{__last_out} = { map { $_ => 1 } @$keys };
     }
     my $text = $self->hash_to_xml( undef, $tree );
     if ( $from && $to ) {
@@ -302,11 +317,19 @@ sub write {
     }
     join( "\n", $decl, $text );
 }
-# ----------------------------------------------------------------
+
 sub parsehttp {
     my $self = shift;
 
-    return $self->parsehttp_lwp(@_) if defined $LWP::UserAgent::VERSION;
+    if ( exists $self->{user_agent} ) {
+        my $agent = $self->{user_agent};
+        $agent .= $USER_AGENT if ( $agent =~ /\s$/s );
+        $self->{__user_agent} = $agent;
+    } else {
+        $self->{__user_agent} = $USER_AGENT;
+    }
+
+    return $self->parsehttp_lwp(@_)  if defined $LWP::UserAgent::VERSION;
     return $self->parsehttp_lite(@_) if defined $HTTP::Lite::VERSION;
 
     local $@;
@@ -318,72 +341,77 @@ sub parsehttp {
 
     Carp::croak "LWP::UserAgent or HTTP::Lite is required: $_[1]";
 }
-# ----------------------------------------------------------------
+
 sub parsehttp_lwp {
-    my $self = shift;
+    my $self   = shift;
     my $method = shift or Carp::croak "Invalid HTTP method";
-    my $url = shift or Carp::croak "Invalid URL";
-    my $body = shift;
+    my $url    = shift or Carp::croak "Invalid URL";
+    my $body   = shift;
 
     my $ua = LWP::UserAgent->new();
     $ua->timeout(10);
     $ua->env_proxy();
+
+    $ua->agent( $self->{__user_agent} );
     my $req = HTTP::Request->new( $method, $url );
-    $req->content( $body ) if defined $body;
-    my $res = $ua->request( $req );
+    $req->content($body) if defined $body;
+    my $res = $ua->request($req);
     return unless $res->is_success();
     my $text = $res->content();
     $self->parse( \$text );
 }
-# ----------------------------------------------------------------
+
 sub parsehttp_lite {
-    my $self = shift;
+    my $self   = shift;
     my $method = shift or Carp::croak "Invalid HTTP method";
-    my $url = shift or Carp::croak "Invalid URL";
-    my $body = shift;
+    my $url    = shift or Carp::croak "Invalid URL";
+    my $body   = shift;
 
     my $http = HTTP::Lite->new();
-    $http->method( $method );
+    $http->method($method);
+    $http->add_req_header( "User-Agent", $self->{__user_agent} );
     $http->{content} = $body if defined $body;
-    $http->request( $url ) or return;
+    $http->request($url) or return;
     my $text = $http->body();
     $self->parse( \$text );
 }
-# ----------------------------------------------------------------
+
 sub parsefile {
     my $self = shift;
     my $file = shift;
     Carp::croak "Invalid filename" unless defined $file;
-    my $text = &read_raw_xml( $file );
+    my $text = &read_raw_xml($file);
     $self->parse( \$text );
 }
-# ----------------------------------------------------------------
+
 sub parse {
     my $self = shift;
     my $textref = ref $_[0] ? $_[0] : \$_[0];
     Carp::croak "Invalid XML source" if ( ref($textref) ne "SCALAR" );
+
     my $to = $self->{internal_encoding} || $INTERNAL_ENCODING;
-    if ( $to ) {
-        my $from = &xml_decl_encoding( $textref );
-        if ( $from ) {
+    if ($to) {
+        my $from = &xml_decl_encoding($textref);
+        if ($from) {
             my $stat = &encode_from_to( $textref, $from, $to );
             Carp::croak "Unsupported encoding: $from" unless $stat;
         }
     }
     if ( exists $self->{force_array} ) {
         my $force = $self->{force_array};
-        $force = [ $force ] unless ref $force;
-        $self->{__force_array} = { map {$_=>1} @$force };
+        $force = [$force] unless ref $force;
+        $self->{__force_array} = { map { $_ => 1 } @$force };
     }
-    my $flat = $self->xml_to_flat( $textref );
+    my $flat = $self->xml_to_flat($textref);
     my $tree = $self->flat_to_tree( $flat, "" );
     wantarray ? ( $tree, $$textref ) : $tree;
 }
-# ----------------------------------------------------------------
+
 sub xml_to_flat {
-    my $self = shift;
-    my $textref = shift;        # reference
-    my $flat = [];
+    my $self    = shift;
+    my $textref = shift;    # reference
+    my $flat    = [];
+    my $prefix = $self->{attr_prefix} || $ATTR_PREFIX;
     while ( $$textref =~ m{
         ([^<]*) <
         ((
@@ -399,71 +427,81 @@ sub xml_to_flat {
         ))
         > ([^<]*)
     }sxg ) {
-        my( $ahead, $match, $typePI, $contPI, $typeCDATA, $contCDATA,
-            $typeDocT, $contDocT,
-            $typeCmnt, $contCmnt, $typeElem, $contElem, $follow ) =
-            ( $1, $2, $3, $4, $5, $6, $7, $8, $9, $10, $11, $12, $13 );
+        my (
+            $ahead,     $match,    $typePI,   $contPI,   $typeCDATA,
+            $contCDATA, $typeDocT, $contDocT, $typeCmnt, $contCmnt,
+            $typeElem,  $contElem, $follow
+          )
+          = ( $1, $2, $3, $4, $5, $6, $7, $8, $9, $10, $11, $12, $13 );
         if ( defined $ahead && $ahead =~ /\S/ ) {
             Carp::carp "Invalid string: [$ahead] before <$match>";
         }
 
-        if ( $typeElem ) {                          ## Element
+        if ($typeElem) {                        # Element
             my $node = {};
             if ( $contElem =~ s#^/## ) {
-                $node->{endTag} ++
-            } elsif ( $contElem =~ s#/$## ) {
+                $node->{endTag}++;
+            }
+            elsif ( $contElem =~ s#/$## ) {
                 # one line
-            } else {
-                $node->{startTag} ++;
+            }
+            else {
+                $node->{startTag}++;
             }
             $node->{tagName} = $1 if ( $contElem =~ s#^(\S+)\s*## );
             unless ( $node->{endTag} ) {
                 my $attr = {};
-                while ( $contElem =~ m/([^\s\=\"\']+)=(?:(")(.*?)"|'(.*?)')/sg ) {
+                while (
+                    $contElem =~ m/([^\s\=\"\']+)=(?:(")(.*?)"|'(.*?)')/sg )
+                {
                     my $key = $1;
                     my $val = &xml_unescape( $2 ? $3 : $4 );
-                    $attr->{"-".$key} = $val;
+                    $attr->{$prefix.$key} = $val;
                 }
                 $node->{attributes} = $attr if scalar keys %$attr;
             }
             push( @$flat, $node );
-        } elsif ( $typeCDATA ) {                    ## CDATASection
+        }
+        elsif ($typeCDATA) {    ## CDATASection
             if ( exists $self->{cdata_scalar_ref} && $self->{cdata_scalar_ref} ) {
-                push( @$flat, \$contCDATA );        # as reference for scalar
-            } else {
-                push( @$flat, $contCDATA );         # as scalar like text node
+                push( @$flat, \$contCDATA );    # as reference for scalar
             }
-        } elsif ( $typeCmnt ) {                     ## Comment
-            # ignore
-        } elsif ( $typeDocT ) {                     ## DocumentType
-            # ignore
-        } elsif ( $typePI ) {                       ## ProcessingInstruction
-            # ignore
-        } else {
+            else {
+                push( @$flat, $contCDATA );     # as scalar like text node
+            }
+        }
+        elsif ($typeCmnt) {                     # Comment (ignore)
+        }
+        elsif ($typeDocT) {                     # DocumentType (ignore)
+        }
+        elsif ($typePI) {                       # ProcessingInstruction (ignore)
+        }
+        else {
             Carp::carp "Invalid Tag: <$match>";
         }
-        if ( $follow =~ /\S/ ) {                    ## text node
+        if ( $follow =~ /\S/ ) {                # text node
             $follow =~ s/^([ \t]*[\r\n])+//s;
             $follow =~ s/([\r\n][ \t]*)+$//s;
-            my $val = &xml_unescape( $follow );
+            my $val = &xml_unescape($follow);
             push( @$flat, $val );
         }
     }
     $flat;
 }
-# ----------------------------------------------------------------
+
 sub flat_to_tree {
-    my $self = shift;
+    my $self   = shift;
     my $source = shift;
     my $parent = shift;
-    my $tree = {};
-    my $text = [];
+    my $tree   = {};
+    my $text   = [];
 
-    while( scalar @$source ) {
+    while ( scalar @$source ) {
         my $node = shift @$source;
+
         # print Data::Dumper::Dumper( $node );
-        if ( ! ref $node || UNIVERSAL::isa( $node, "SCALAR" )) {
-            push( @$text, $node );                  ## cdata or text node
+        if ( !ref $node || UNIVERSAL::isa( $node, "SCALAR" ) ) {
+            push( @$text, $node );              # cdata or text node
             next;
         }
         my $name = $node->{tagName};
@@ -472,7 +510,7 @@ sub flat_to_tree {
             Carp::croak "Invalid tag sequence: <$parent></$name>";
         }
         my $elem = $node->{attributes};
-        if ( $node->{startTag} ) {                  ## recursive call
+        if ( $node->{startTag} ) {              # recursive call
             my $child = $self->flat_to_tree( $source, $name );
             if ( ref $elem && scalar keys %$elem ) {
                 if ( ref $child ) {
@@ -480,193 +518,218 @@ sub flat_to_tree {
                     foreach my $key ( keys %$child ) {
                         $elem->{$key} = $child->{$key};
                     }
-                } elsif ( defined $child ) {
+                }
+                elsif ( defined $child ) {
                     # some attributes and text node
                     $elem->{"#text"} = $child;
                 }
-            } else {
+            }
+            else {
                 # no attributes and text node or nothing
                 $elem = $child;
             }
         }
-#       next unless defined $elem;
+
+        # next unless defined $elem;
         $tree->{$name} ||= [];
-        push( @{$tree->{$name}}, $elem );
+        push( @{ $tree->{$name} }, $elem );
     }
     foreach my $key ( keys %$tree ) {
         next if $self->{__force_array}->{$key};
-        next if ( 1 < scalar @{$tree->{$key}} );
-        $tree->{$key} = shift @{$tree->{$key}};
+        next if ( 1 < scalar @{ $tree->{$key} } );
+        $tree->{$key} = shift @{ $tree->{$key} };
     }
     if ( scalar @$text ) {
         $text = shift @$text if ( scalar @$text == 1 );
         if ( scalar keys %$tree ) {
             # some child nodes and also text node
             $tree->{"#text"} = $text;
-        } else {
+        }
+        else {
             # only text node without child nodes
             $tree = $text;
         }
     }
     $tree;
 }
-# ----------------------------------------------------------------
+
 sub hash_to_xml {
-    my $self = shift;
-    my $name = shift;
-    my $hash = shift;
-    my $out = [];
-    my $attr = [];
-    my $allkeys = [ sort keys %$hash ];
-    my $firstkeys = [ grep {$self->{__first_out}->{$_}} @$allkeys ] if ref $self->{__first_out};
-    my $lastkeys  = [ grep {$self->{__last_out}->{$_}}  @$allkeys ] if ref $self->{__last_out};
-    $allkeys = [ grep {! $self->{__first_out}->{$_}} @$allkeys ] if ref $self->{__first_out};
-    $allkeys = [ grep {! $self->{__last_out}->{$_}}  @$allkeys ] if ref $self->{__last_out};
+    my $self      = shift;
+    my $name      = shift;
+    my $hash      = shift;
+    my $out       = [];
+    my $attr      = [];
+    my $allkeys   = [ sort keys %$hash ];
+    my $firstkeys = [ grep { $self->{__first_out}->{$_} } @$allkeys ] if ref $self->{__first_out};
+    my $lastkeys = [ grep { $self->{__last_out}->{$_} } @$allkeys ] if ref $self->{__last_out};
+    $allkeys = [ grep { !$self->{__first_out}->{$_} } @$allkeys ] if ref $self->{__first_out};
+    $allkeys = [ grep { !$self->{__last_out}->{$_} } @$allkeys ] if ref $self->{__last_out};
+    my $prefix = $self->{attr_prefix} || $ATTR_PREFIX;
+    $prefix = "\Q$prefix\E";
+
     foreach my $loopkey ( $firstkeys, $allkeys, $lastkeys ) {
         next unless ref $loopkey;
-        foreach my $key ( grep {!/^-/} @$loopkey ) {
+        foreach my $key ( grep { !/^$prefix/ } @$loopkey ) {
             my $val = $hash->{$key};
-            if ( ! defined $val ) {
+            if ( !defined $val ) {
                 push( @$out, "<$key />" );
-            } elsif ( UNIVERSAL::isa( $val, "ARRAY" ) ) {
+            }
+            elsif ( UNIVERSAL::isa( $val, "ARRAY" ) ) {
                 my $child = $self->array_to_xml( $key, $val );
                 push( @$out, $child );
-            } elsif ( UNIVERSAL::isa( $val, "SCALAR" ) ) {
+            }
+            elsif ( UNIVERSAL::isa( $val, "SCALAR" ) ) {
                 my $child = $self->scalaref_to_cdata( $key, $val );
                 push( @$out, $child );
-            } elsif ( ref $val ) {
+            }
+            elsif ( ref $val ) {
                 my $child = $self->hash_to_xml( $key, $val );
                 push( @$out, $child );
-            } else {
+            }
+            else {
                 my $child = $self->scalar_to_xml( $key, $val );
                 push( @$out, $child );
             }
         }
-        foreach my $key ( grep { /^-/} @$loopkey ) {
-            my $name = ( $key =~ /^-(.*)$/s )[0];
-            my $val = &xml_escape($hash->{$key});
-            push( @$attr, " ".$name.'="'.$val.'"' );
+        foreach my $key ( grep { /^$prefix/ } @$loopkey ) {
+            my $name = ( $key =~ /^$prefix(.*)$/s )[0];
+            my $val = &xml_escape( $hash->{$key} );
+            push( @$attr, " " . $name . '="' . $val . '"' );
         }
     }
     my $jattr = join( "", @$attr );
-#   s/^(\s*<)/  $1/mg foreach @$out;            # indent
+
+    # s/^(\s*<)/  $1/mg foreach @$out;              # indent
     my $text = join( "", @$out );
     if ( defined $name ) {
         if ( scalar @$out ) {
             if ( $text =~ /\n/s ) {
                 $text = "<$name$jattr>\n$text</$name>\n";
-            } else {
+            }
+            else {
                 $text = "<$name$jattr>$text</$name>\n";
             }
-        } else {
+        }
+        else {
             $text = "<$name$jattr />\n";
         }
     }
     $text;
 }
-# ----------------------------------------------------------------
+
 sub array_to_xml {
-    my $self = shift;
-    my $name = shift;
+    my $self  = shift;
+    my $name  = shift;
     my $array = shift;
-    my $out = [];
-    foreach my $val ( @$array ) {
-        if ( ! defined $val ) {
+    my $out   = [];
+    foreach my $val (@$array) {
+        if ( !defined $val ) {
             push( @$out, "<$name />\n" );
-        } elsif ( UNIVERSAL::isa( $val, "ARRAY" ) ) {
+        }
+        elsif ( UNIVERSAL::isa( $val, "ARRAY" ) ) {
             my $child = $self->array_to_xml( $name, $val );
             push( @$out, $child );
-        } elsif ( UNIVERSAL::isa( $val, "SCALAR" ) ) {
+        }
+        elsif ( UNIVERSAL::isa( $val, "SCALAR" ) ) {
             my $child = $self->scalaref_to_cdata( $name, $val );
             push( @$out, $child );
-        } elsif ( ref $val ) {
+        }
+        elsif ( ref $val ) {
             my $child = $self->hash_to_xml( $name, $val );
             push( @$out, $child );
-        } else {
+        }
+        else {
             my $child = $self->scalar_to_xml( $name, $val );
             push( @$out, $child );
         }
     }
-#   s/^(\s*<)/  $1/mg foreach @$out;            # indent
+
+    # s/^(\s*<)/  $1/mg foreach @$out;              # indent
     my $text = join( "", @$out );
     $text;
 }
-# ----------------------------------------------------------------
+
 sub scalaref_to_cdata {
     my $self = shift;
     my $name = shift;
-    my $ref = shift;
-    my $text = '<![CDATA['.$$ref.']]>';
+    my $ref  = shift;
+    my $text = '<![CDATA[' . $$ref . ']]>';
     $text = "<$name>$text</$name>\n" if ( $name ne "#text" );
     $text;
 }
-# ----------------------------------------------------------------
+
 sub scalar_to_xml {
-    my $self = shift;
-    my $name = shift;
+    my $self   = shift;
+    my $name   = shift;
     my $scalar = shift;
-    my $copy = $scalar;
-    my $text = &xml_escape($copy);
+    my $copy   = $scalar;
+    my $text   = &xml_escape($copy);
     $text = "<$name>$text</$name>\n" if ( $name ne "#text" );
     $text;
 }
-# ----------------------------------------------------------------
+
 sub write_raw_xml {
     my $file = shift;
-    my $fh = Symbol::gensym();
+    my $fh   = Symbol::gensym();
     open( $fh, ">$file" ) or Carp::croak "$! - $file";
     print $fh @_;
-    close( $fh );
+    close($fh);
 }
-# ----------------------------------------------------------------
+
 sub read_raw_xml {
     my $file = shift;
-    my $fh = Symbol::gensym();
+    my $fh   = Symbol::gensym();
     open( $fh, $file ) or Carp::croak "$! - $file";
     local $/ = undef;
     my $text = <$fh>;
-    close( $fh );
+    close($fh);
     $text;
 }
-# ----------------------------------------------------------------
+
 sub xml_decl_encoding {
     my $textref = shift;
-    my $line = ( $$textref =~ /^([^\r\n]*)/s )[0];
-    my $args = ( $$textref =~ /^\s*<\?xml(\s+\S.*)\?>/s )[0] or return;
+    my $line    = ( $$textref =~ /^([^\r\n]*)/s )[0];
+    my $args    = ( $$textref =~ /^\s*<\?xml(\s+\S.*)\?>/s )[0] or return;
     my $getcode = ( $args =~ /\s+encoding="(.*?)"/ )[0] or return;
     $getcode;
 }
-# ----------------------------------------------------------------
+
 sub encode_from_to {
-    my( $str, $from, $to ) = @_;
-    return if ( $from eq "" );
-    return if ( $to eq "" );
+    my ( $str, $from, $to ) = @_;
+    return     if ( $from     eq "" );
+    return     if ( $to       eq "" );
     return $to if ( uc($from) eq uc($to) );
     local $@;
     eval { require Encode; } unless defined $Encode::VERSION;
     if ( defined $Encode::VERSION ) {
         Encode::from_to( $$str, $from, $to, Encode::FB_XMLCREF() );
-    } elsif (( uc($from) eq "ISO-8859-1" || uc($from) eq "US-ASCII" ||
-               uc($from) eq "LATIN-1" ) && uc($to) eq "UTF-8" ) {
-        &latin1_to_utf8( $str );
-    } else {
-        my $jfrom = &get_jcode_name( $from );
-        my $jto   = &get_jcode_name( $to );
+    }
+    elsif ( (  uc($from) eq "ISO-8859-1"
+            || uc($from) eq "US-ASCII"
+            || uc($from) eq "LATIN-1" ) && uc($to) eq "UTF-8" ) {
+        &latin1_to_utf8($str);
+    }
+    else {
+        my $jfrom = &get_jcode_name($from);
+        my $jto   = &get_jcode_name($to);
         return $to if ( uc($jfrom) eq uc($jto) );
         if ( $jfrom && $jto ) {
             eval { require Jcode; } unless defined $Jcode::VERSION;
             if ( defined $Jcode::VERSION ) {
                 Jcode::convert( $str, $jto, $jfrom );
-            } else {
-                Carp::croak "Encode.pm or Jcode.pm is required: $from to $to";
             }
-        } else {
+            else {
+                Carp::croak
+                  "Encode.pm or Jcode.pm is required: $from to $to";
+            }
+        }
+        else {
             Carp::croak "Encode.pm is required: $from to $to";
         }
     }
     $to;
 }
-# ----------------------------------------------------------------
+
 sub latin1_to_utf8 {
     my $strref = shift;
     $$strref =~ s{
@@ -675,22 +738,25 @@ sub latin1_to_utf8 {
         pack( "C2" => 0xC0|(ord($1)>>6),0x80|(ord($1)&0x3F) )
     }exg;
 }
-# ----------------------------------------------------------------
+
 sub get_jcode_name {
     my $src = shift;
     my $dst;
     if ( $src =~ /^utf-?8$/i ) {
         $dst = "utf8";
-    } elsif ( $src =~ /^euc.*jp$/i ) {
+    }
+    elsif ( $src =~ /^euc.*jp$/i ) {
         $dst = "euc";
-    } elsif ( $src =~ /^(shift.*jis|cp932|windows-31j)$/i ) {
+    }
+    elsif ( $src =~ /^(shift.*jis|cp932|windows-31j)$/i ) {
         $dst = "sjis";
-    } elsif ( $src =~ /^iso-2022-jp/ ) {
+    }
+    elsif ( $src =~ /^iso-2022-jp/ ) {
         $dst = "jis";
     }
     $dst;
 }
-# ----------------------------------------------------------------
+
 sub xml_escape {
     my $str = shift;
     $str =~ s/&/&amp;/g;
@@ -699,7 +765,7 @@ sub xml_escape {
     $str =~ s/"/&quot;/g;
     $str;
 }
-# ----------------------------------------------------------------
+
 sub xml_unescape {
     my $str = shift;
     $str =~ s/&quot;/"/g;
@@ -708,6 +774,5 @@ sub xml_unescape {
     $str =~ s/&amp;/&/g;
     $str;
 }
-# ----------------------------------------------------------------
-;1;
-# ----------------------------------------------------------------
+
+1;
